Learn R Programming

daltoolbox (version 1.3.767)

cla_majority: Majority Baseline Classifier

Description

Trivial classifier that always predicts the most frequent class observed in the training data.

Usage

cla_majority(attribute, slevels)

Value

A classification object of class cla_majority.

Arguments

attribute

Name of the target attribute to predict.

slevels

Possible class labels for the target classification problem.

Details

Useful as a minimum reference point. If a stronger classifier does not outperform this learner, it is often worth revisiting the predictors, the sampling strategy, or the evaluation protocol before tuning models.

References

Witten, I. H., Frank, E., Hall, M. A., and Pal, C. J. (2016). Data Mining: Practical Machine Learning Tools and Techniques (4th ed.). Morgan Kaufmann.

Examples

Run this code
data(iris)
slevels <- levels(iris$Species)
model <- cla_majority("Species", slevels)

# preparing dataset for random sampling
sr <- sample_random()
sr <- train_test(sr, iris)
train <- sr$train
test <- sr$test

model <- fit(model, train)

prediction <- predict(model, test)
predictand <- adjust_class_label(test[, "Species"])
test_eval <- evaluate(model, predictand, prediction)
test_eval$metrics

Run the code above in your browser using DataLab