| patutils | R Documentation |
Utility object that groups filtering helpers and evaluation metrics for pattern mining.
patutils()
The object groups two kinds of helpers:
quality-filter builders such as quality_min() and quality_max()
descriptive metrics for discovered patterns such as pattern count, mean support, mean confidence, mean lift, mean length, and retained ratio after filtering
returns a patutils object
utils <- patutils()
utils$quality_min(confidence = 0.8, lift = 1.1)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.