Learn R Programming

daltoolbox (version 1.3.767)

sample_random: Random Sampling

Description

Train/test split and k-fold partitioning by simple random sampling.

Usage

sample_random()

Arguments

Value

An object of class sample_random.

Details

This is the simplest partitioning strategy in daltoolbox. It is a good starting point when the dataset is reasonably balanced and the user wants to understand the train/test workflow before moving to stratified or more specialized sampling schemes.

Examples

Run this code
# using random sampling
sample <- sample_random()
tt <- train_test(sample, iris)

# distribution of train
table(tt$train$Species)

# preparing dataset into four folds
folds <- k_fold(sample, iris, 4)

# distribution of folds
tbl <- NULL
for (f in folds) {
  tbl <- rbind(tbl, table(f$Species))
}
head(tbl)

Run the code above in your browser using DataLab