powered by
Model-based clustering using mclust::Mclust.
mclust::Mclust
cluster_gmm(G = NULL, modelNames = NULL)
returns a GMM clustering object.
number of mixture components (clusters). If NULL, Mclust chooses.
Mclust
optional character vector of model names passed to Mclust.
Fits a Gaussian mixture model and returns the MAP classification. The fitted model is stored in obj$model. Requires the mclust package.
obj$model
mclust
Fraley, C., & Raftery, A. E. (2002). Model-based clustering. JASA.
data(iris) model <- cluster_gmm(G = 3) model <- fit(model, iris[,1:4]) clu <- cluster(model, iris[,1:4]) table(clu)
Run the code above in your browser using DataLab