initial imputation method for numeric source columns: "median" or "mean"
Details
The target column is the attribute to be imputed. The source columns are the predictors used
to estimate missing target values. If sources = NULL, all supported columns except the target are used.
Missing values in source columns can be pre-imputed by a simpler method before fitting the predictive model.