predictor_prepare_fit: Prepare predictor fit data
Description
Normalizes supervised fit input and records predictor columns by
removing the target attribute from the data columns.
Usage
predictor_prepare_fit(obj, data)
Value
returns a list with the updated object and normalized data
Arguments
- obj
predictor-like object containing attribute
- data
training data